@@ -29,6 +29,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdint.h>
 
 #include "gnc-numeric.h"
 
@@ -40,10 +41,13 @@
 
 /* static short module = MOD_ENGINE; */
 static const gint64 pten[] = { 1, 10, 100, 1000, 10000, 100000, 1000000,
-			       10000000, 100000000, 1000000000, 10000000000,
-			       100000000000, 1000000000000, 10000000000000,
-			       100000000000000, 10000000000000000,
-			       100000000000000000, 1000000000000000000};
+			       10000000, 100000000, 1000000000,
+			       INT64_C(10000000000), INT64_C(100000000000),
+			       INT64_C(1000000000000), INT64_C(10000000000000),
+			       INT64_C(100000000000000),
+			       INT64_C(10000000000000000),
+			       INT64_C(100000000000000000),
+			       INT64_C(1000000000000000000)};
 #define POWTEN_OVERFLOW -5
 
 static inline gint64
